'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _ramda = require('ramda');

var _isJsonPath = require('./isJsonPath');

var _isJsonPath2 = _interopRequireDefault(_isJsonPath);

var _isOperation = require('./isOperation');

var _isOperation2 = _interopRequireDefault(_isOperation);

var _isValueForOperation = require('./isValueForOperation');

var _isValueForOperation2 = _interopRequireDefault(_isValueForOperation);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Tests if a given object is a valid JSON Patch object
 * according to https://tools.ietf.org/html/rfc6902
 *
 * @memberof jsonPatch
 * @param {object} jsonPatch - the json patch to be tested
 * @return {boolean} testResult - true|false if the object is a valid JSON Patch
 * @example
 *
 * let patch1 = { op: 'add', path: '/foo', value: 'bar' }
 * let patch2 = { op: 'add', path: 'foo', value: 'bar' }
 * isValidPatch(patch1) // true
 * isValidPatch(patch2) // false
 *
 */
var isValidPatch = (0, _ramda.allPass)([(0, _ramda.pipe)((0, _ramda.prop)('path'), _isJsonPath2.default), (0, _ramda.pipe)((0, _ramda.prop)('op'), _isOperation2.default), (0, _ramda.pipe)((0, _ramda.props)(['op', 'value', 'from']), (0, _ramda.filter)((0, _ramda.compose)(_ramda.not, _ramda.isNil)), (0, _ramda.apply)(_isValueForOperation2.default))]);

exports.default = isValidPatch;
//# sourceMappingURL=isPatch.js.map
