import { compose, allPass, pipe, props, filter, isNil, not, apply, prop } from 'ramda'
import isJsonPath from './isJsonPath'
import isOperation from './isOperation'
import isValueForOperation from './isValueForOperation'

/**
 * Tests if a given object is a valid JSON Patch object
 * according to https://tools.ietf.org/html/rfc6902
 *
 * @memberof jsonPatch
 * @param {object} jsonPatch - the json patch to be tested
 * @return {boolean} testResult - true|false if the object is a valid JSON Patch
 * @example
 *
 * let patch1 = { op: 'add', path: '/foo', value: 'bar' }
 * let patch2 = { op: 'add', path: 'foo', value: 'bar' }
 * isValidPatch(patch1) // true
 * isValidPatch(patch2) // false
 *
 */
const isValidPatch = allPass([
  pipe(prop('path'), isJsonPath),
  pipe(prop('op'), isOperation),
  pipe(
    props(['op', 'value', 'from']),
    filter(compose(not, isNil)),
    apply(isValueForOperation)
  )
])

export default isValidPatch
